ValueCallBack<T> class

Constructors

ValueCallBack({required ValueSuccessCallback<T> onSuccess, required ValueErrorCallback onError})

Properties

hashCode → int
The hash code for this object.
no setterinherited
onError ↔ ValueErrorCallback
getter/setter pair
onSuccess ↔ ValueSuccessCallback<T>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited