TUIConferenceInvitationManagerImpl class
- Inheritance
-
- Object
- TUIConferenceInvitationManager
- TUIConferenceInvitationManagerImpl
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
accept(
String conferenceId) → Future< TUIActionCallback> -
Accept invitation.
override
-
addObserver(
TUIConferenceInvitationObserver observer) → void -
Add event callback.
override
-
cancelInvitation(
String conferenceId, List< String> userIdList) → Future<TUIActionCallback> -
Cancel invitation.
override
-
getInvitationList(
String conferenceId, String cursor, int count) → Future< TUIValueCallBack< TUIInvitationListResult> > -
Get invitation list.
override
-
inviteUsers(
String conferenceId, List< String> userIdList, int timeout, String extensionInfo) → Future<TUIValueCallBack< TUIInviteUsersResult> > -
Invite users to the conference.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reject(
String conferenceId, TUIInvitationRejectedReason reason) → Future< TUIActionCallback> -
Reject invitation.
override
-
removeObserver(
TUIConferenceInvitationObserver observer) → void -
Remove event callback.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited